searchData={"items":[{"type":"module","title":"Eunomo","doc":"Sorts `alias`, `import` and `require` definitions alphabetically.\n\nThe sorting does not happen globally. Instead each \"block\" is sorted separately. An \"block\" is a\nset of expressions that are _not_ separated by at least one empty newline or other\nnon-(alias,import,require) expressions. Note that the file is first formatter by the default\nElixir code formatter! All directly preceding comment lines are sorted as part of the\nexpression.\n\nOnly the order of lines is modified by this formatter. Neither the overall number of lines nor\nthe content of a single line will change.\n\nBesides the options `Code.format_string!/2` and `Mix.Tasks.Format`, the `.formatter.exs` file\nsupports the following Eunomo specific options:\n\n  * `:eunomo_opts` (a keyword list) - toggles expressions to be sorted. Available switches:\n      * `sort_alias: :boolean`\n      * `sort_import: :boolean`\n      * `sort_require: :boolean`\n\n    By default all are `false` & the behavior is identical to the default formatter.\n\nA complete `my_app`'s `.formatter.exs` would look like this:\n\n    # my_app/.formatter.exs\n    [\n      plugins: [Eunomo],\n      eunomo_opts: [\n        sort_alias: true,\n        sort_import: true,\n        sort_require: true\n      ],\n      inputs: [\"{mix,.formatter}.exs\", \"{config,lib,test}/**/*.{ex,exs}\"]\n    ]","ref":"Eunomo.html"},{"type":"module","title":"Examples - Eunomo","doc":"Sorting only alias expressions:\n    iex> code_snippet = \"\"\"\n    ...> # Comment 1\n    ...> alias Eunomo.Z.{L, I}\n    ...> alias Eunomo.Z\n    ...> # Comment 2\n    ...> # Comment 2.1\n    ...> alias __MODULE__.B\n    ...> # Comment 3\n    ...> alias __MODULE__.A\n    ...> alias Eunomo.C\n    ...> alias Eunomo.{\n    ...>   L,\n    ...>   B,\n    ...>   # test\n    ...> }\n    ...> \\n# Comment 4\n    ...> alias Eunomo.PG.Repo\n    ...> alias A\n    ...> alias Eunomo.Patient\n    ...> \"\"\"\n    ...> Eunomo.format(code_snippet, [eunomo_opts: [sort_alias: true]])\n    \"\"\"\n    # Comment 3\n    alias __MODULE__.A\n    # Comment 2\n    # Comment 2.1\n    alias __MODULE__.B\n    alias Eunomo.C\n    alias Eunomo.Z\n    # Comment 1\n    alias Eunomo.Z.{L, I}\n    \\nalias Eunomo.{\n      L,\n      B\n      # test\n    }\n    \\nalias A\n    alias Eunomo.Patient\n    # Comment 4\n    alias Eunomo.PG.Repo\n    \"\"\"\n\nSorting only import expressions:\n    iex> code_snippet = \"\"\"\n    ...> # Comment 1\n    ...> import Eunomo.Z.{L, I}\n    ...> import Eunomo.Z, only: [hello_world: 0]\n    ...> # Comment 2\n    ...> # Comment 2.1\n    ...> import B, expect: [callback: 1]\n    ...> import Eunomo.C\n    ...> import Eunomo.{\n    ...>   L,\n    ...>   B,\n    ...>   # test\n    ...> }\n    ...> \\nimport Eunomo.PG.Repo\n    ...> import A\n    ...> import Eunomo.Patient\n    ...> \"\"\"\n    ...> Eunomo.format(code_snippet, [eunomo_opts: [sort_import: true]])\n    \"\"\"\n    # Comment 2\n    # Comment 2.1\n    import B, expect: [callback: 1]\n    import Eunomo.C\n    import Eunomo.Z, only: [hello_world: 0]\n    # Comment 1\n    import Eunomo.Z.{L, I}\n    \\nimport Eunomo.{\n      L,\n      B\n      # test\n    }\n    \\nimport A\n    import Eunomo.Patient\n    import Eunomo.PG.Repo\n    \"\"\"\n\n\nSorting only require expressions:\n    iex> code_snippet = \"\"\"\n    ...> # Comment 1\n    ...> require Eunomo.Z.{L, I}\n    ...> require Eunomo.Z\n    ...> # Comment 2\n    ...> # Comment 2.1\n    ...> require Eunomo.C\n    ...> require Eunomo.{\n    ...>   L,\n    ...>   B,\n    ...>   # test\n    ...> }\n    ...> \\nrequire Eunomo.PG.Repo\n    ...> require A\n    ...> require Eunomo.Patient\n    ...> \"\"\"\n    ...> Eunomo.format(code_snippet, [eunomo_opts: [sort_require: true]])\n    \"\"\"\n    # Comment 2\n    # Comment 2.1\n    require Eunomo.C\n    require Eunomo.Z\n    # Comment 1\n    require Eunomo.Z.{L, I}\n    \\nrequire Eunomo.{\n      L,\n      B\n      # test\n    }\n    \\nrequire A\n    require Eunomo.Patient\n    require Eunomo.PG.Repo\n    \"\"\"","ref":"Eunomo.html#module-examples"},{"type":"extras","title":"README","doc":"# Eunomo\n\nThe default Elixir formatter has the philosophy of not modifying non metadata parts of the AST.\n`Eunomo` does not adhere to this philosophy and is meant to be used as an extension to the default\nformatter. As of now, the single use case is to sort `import`, `alias` and `require` definitions\nalphabetically.\n\nSee [https://hexdocs.pm/eunomo](https://hexdocs.pm/eunomo) for further documentation &\nhttps://github.com/Roberto-XY/eunomo for the source code.","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"The package can be installed by adding `eunomo` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:eunomo, \"~> 3.0.0\", only: :dev}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Elixir `>= 1.13.0` & version `3.0.0` - README","doc":"Uses Elixir formatter [plugin\nsystem](https://hexdocs.pm/mix/1.13.0/Mix.Tasks.Format.html#module-plugins).\n\n```elixir\n# .formatter.exs\n[\n  # Usage of new formatter plugin system in Elixir `>= 1.13.0`.\n  plugins: [Eunomo],\n  eunomo_opts: [\n    sort_alias: true,\n    sort_import: true,\n    sort_require: true\n  ],\n  inputs: [\"{mix,.formatter}.exs\", \"{config,lib,test}/**/*.{ex,exs}\"]\n]\n```\n\nRunning `mix format` is going to take over as usal from here. All `mix format` options also apply to\nEunomo plugins.","ref":"readme.html#elixir-1-13-0-version-3-0-0"},{"type":"extras","title":"Elixir `< 1.13.0` & version `0.1.3 ` - README","doc":"Before Elixir version `1.13.0`, there was no way to hook plugins into the default formatter. Hence\ntwo Mix tasks were provided: [`mix\neunomo.gen.config`](https://hexdocs.pm/eunomo/0.1.3/Mix.Tasks.Eunomo.Gen.Config.html) & [`mix\neunomo`](https://hexdocs.pm/eunomo/0.1.3/Mix.Tasks.Eunomo.html#content). This approach does not\nplay nicely with umbrella applications.","ref":"readme.html#elixir-1-13-0-version-0-1-3"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}